from typing import Any, Dict, List, Type, TypeVar, Union, cast

from attrs import define as _attrs_define, field as _attrs_field

T = TypeVar("T", bound="UpdateHeartbeatInput")


@_attrs_define
class UpdateHeartbeatInput:
    """
    Attributes:
        name (str):
        description (str):
        link (Union[None, str]):
        service (int):
    """

    name: str
    description: str
    link: Union[None, str]
    service: int
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        name = self.name

        description = self.description

        link: Union[None, str]
        link = self.link

        service = self.service

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "name": name,
                "description": description,
                "link": link,
                "service": service,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        name = d.pop("name")

        description = d.pop("description")

        def _parse_link(data: object) -> Union[None, str]:
            if data is None:
                return data
            return cast(Union[None, str], data)

        link = _parse_link(d.pop("link"))

        service = d.pop("service")

        update_heartbeat_input = cls(
            name=name,
            description=description,
            link=link,
            service=service,
        )

        update_heartbeat_input.additional_properties = d
        return update_heartbeat_input

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
